==> storagehub-1.4.0-20211013.090423-11-sources.jar: org/gcube/data/access/storagehub/services/interfaces/ACLManagerInterface.java <==
package org.gcube.data.access.storagehub.services.interfaces;

import java.util.List;

import javax.jcr.RepositoryException;
import javax.jcr.Session;

import org.gcube.common.storagehub.model.acls.ACL;
import org.gcube.common.storagehub.model.acls.AccessType;
import org.gcube.common.storagehub.model.exceptions.BackendGenericError;
import org.gcube.common.storagehub.model.exceptions.StorageHubException;
import org.gcube.common.storagehub.model.items.Item;
import org.gcube.common.storagehub.model.items.SharedFolder;

public interface ACLManagerInterface {

	/**
	 * returns the AccessType for all the users in a shared folder
	 *
	 * @exception {@link RepositoryException} when a generic jcr error occurs
	 * @exception {@link UserNotAuthorizedException} when the caller is not authorized to access to the shared folder
	 */
	List<ACL> get(Item item, Session session) throws RepositoryException, BackendGenericError;

	/**
	 * Set a new AccessType for a user in a shared folder or VRE folder
	 * 
	 * 
	 * @param String user
	 * @param accessType accessType
	 * 
	 * @exception {@link RepositoryException} when a generic jcr error occurs
	 * @exception {@link UserNotAuthorizedException} when the caller is not ADMINISTRATOR of the shared folder
	 * @exception {@link InvalidCallParameters} when the folder is not shared with the specified user
	 * @exception {@link InvalidItemException} when the folder is not share
	 */
	void update(String targetUser, SharedFolder folder, AccessType accessType, Session session) throws RepositoryException, StorageHubException;

	void delete(String targetUser, SharedFolder folder, Session session)
			throws RepositoryException, StorageHubException;

}

==> storagehub-2.1.3-20260202.114515-5-sources.jar: org/gcube/data/access/storagehub/services/interfaces/ACLManagerInterface.java <==
package org.gcube.data.access.storagehub.services.interfaces;

import java.util.List;

import javax.jcr.Node;
import javax.jcr.RepositoryException;
import javax.jcr.Session;

import org.gcube.common.storagehub.model.acls.ACL;
import org.gcube.common.storagehub.model.acls.AccessType;
import org.gcube.common.storagehub.model.exceptions.BackendGenericError;
import org.gcube.common.storagehub.model.exceptions.InvalidCallParameters;
import org.gcube.common.storagehub.model.exceptions.InvalidItemException;
import org.gcube.common.storagehub.model.exceptions.StorageHubException;
import org.gcube.common.storagehub.model.exceptions.UserNotAuthorizedException;
import org.gcube.common.storagehub.model.items.Item;

public interface ACLManagerInterface {

	/**
	 * returns the AccessType for all the users in a shared folder
	 *
	 * @exception {@link RepositoryException} when a generic jcr error occurs
	 * @exception {@link UserNotAuthorizedException} when the caller is not authorized to access to the shared folder
	 */
	List<ACL> getByItem(Item item, Session session) throws RepositoryException, BackendGenericError;

	List<ACL> get(Node node, Session session) throws RepositoryException, BackendGenericError;
	
	/**
	 * Set a new AccessType for a user in a shared folder or VRE folder
	 * 
	 * 
	 * @param String user
	 * @param accessType accessType
	 * 
	 * @exception {@link RepositoryException} when a generic jcr error occurs
	 * @exception {@link UserNotAuthorizedException} when the caller is not ADMINISTRATOR of the shared folder
	 * @exception {@link InvalidCallParameters} when the folder is not shared with the specified user
	 * @exception {@link InvalidItemException} when the folder is not share
	 */
	void update(String targetUser, Node node, AccessType accessType, Session session) throws RepositoryException, StorageHubException;

	void delete(String targetUser, Node node, Session session)
			throws RepositoryException, StorageHubException;

	

}
